# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: messaging_model.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import common_model_pb2 as common__model__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='messaging_model.proto',
  package='com.elarian.hera.proto',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15messaging_model.proto\x12\x16\x63om.elarian.hera.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x12\x63ommon_model.proto\"c\n\x16MessagingChannelNumber\x12\x39\n\x07\x63hannel\x18\x01 \x01(\x0e\x32(.com.elarian.hera.proto.MessagingChannel\x12\x0e\n\x06number\x18\x02 \x01(\t\"Q\n\x10MediaMessageBody\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x30\n\x05media\x18\x02 \x01(\x0e\x32!.com.elarian.hera.proto.MediaType\"\x96\x01\n\x13LocationMessageBody\x12\x10\n\x08latitude\x18\x01 \x01(\x01\x12\x11\n\tlongitude\x18\x02 \x01(\x01\x12+\n\x05label\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x61\x64\x64ress\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x82\x01\n\x10\x45mailMessageBody\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x12\n\nbody_plain\x18\x02 \x01(\t\x12\x11\n\tbody_html\x18\x03 \x01(\t\x12\x0f\n\x07\x63\x63_list\x18\x04 \x03(\t\x12\x10\n\x08\x62\x63\x63_list\x18\x05 \x03(\t\x12\x13\n\x0b\x61ttachments\x18\x06 \x03(\t\"\x99\x01\n\x13TemplateMessageBody\x12\n\n\x02id\x18\x01 \x01(\t\x12G\n\x06params\x18\x02 \x03(\x0b\x32\x37.com.elarian.hera.proto.TemplateMessageBody.ParamsEntry\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"j\n\rSayCallAction\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x38\n\x05voice\x18\x02 \x01(\x0e\x32).com.elarian.hera.proto.TextToSpeechVoice\x12\x11\n\tplay_beep\x18\x03 \x01(\x08\"\x1d\n\x0ePlayCallAction\x12\x0b\n\x03url\x18\x01 \x01(\t\"\x9f\x02\n\x13GetDigitsCallAction\x12\x34\n\x03say\x18\x01 \x01(\x0b\x32%.com.elarian.hera.proto.SayCallActionH\x00\x12\x36\n\x04play\x18\x02 \x01(\x0b\x32&.com.elarian.hera.proto.PlayCallActionH\x00\x12*\n\x07timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x33\n\rfinish_on_key\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\nnum_digits\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\x08\n\x06prompt\"\xc9\x02\n\x16GetRecordingCallAction\x12\x34\n\x03say\x18\x01 \x01(\x0b\x32%.com.elarian.hera.proto.SayCallActionH\x00\x12\x36\n\x04play\x18\x02 \x01(\x0b\x32&.com.elarian.hera.proto.PlayCallActionH\x00\x12*\n\x07timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12-\n\nmax_length\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x33\n\rfinish_on_key\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x11\n\tplay_beep\x18\x06 \x01(\x08\x12\x14\n\x0ctrim_silence\x18\x07 \x01(\x08\x42\x08\n\x06prompt\"\x19\n\x17RecordSessionCallAction\"\x8f\x02\n\x0e\x44ialCallAction\x12@\n\x10\x63ustomer_numbers\x18\x01 \x03(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x0e\n\x06record\x18\x02 \x01(\x08\x12\x12\n\nsequential\x18\x03 \x01(\x08\x12\x33\n\rringback_tone\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tcaller_id\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0cmax_duration\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\"w\n\x11\x45nqueueCallAction\x12\x30\n\nhold_music\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\nqueue_name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x9d\x01\n\x11\x44\x65queueCallAction\x12\x46\n\x0e\x63hannel_number\x18\x01 \x01(\x0b\x32..com.elarian.hera.proto.MessagingChannelNumber\x12\x0e\n\x06record\x18\x02 \x01(\x08\x12\x30\n\nqueue_name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x12\n\x10RejectCallAction\"!\n\x12RedirectCallAction\x12\x0b\n\x03url\x18\x01 \x01(\t\"\x8f\x05\n\x0fVoiceCallAction\x12\x34\n\x03say\x18\x01 \x01(\x0b\x32%.com.elarian.hera.proto.SayCallActionH\x00\x12\x36\n\x04play\x18\x02 \x01(\x0b\x32&.com.elarian.hera.proto.PlayCallActionH\x00\x12\x41\n\nget_digits\x18\x03 \x01(\x0b\x32+.com.elarian.hera.proto.GetDigitsCallActionH\x00\x12\x36\n\x04\x64ial\x18\x04 \x01(\x0b\x32&.com.elarian.hera.proto.DialCallActionH\x00\x12I\n\x0erecord_session\x18\x05 \x01(\x0b\x32/.com.elarian.hera.proto.RecordSessionCallActionH\x00\x12G\n\rget_recording\x18\x06 \x01(\x0b\x32..com.elarian.hera.proto.GetRecordingCallActionH\x00\x12<\n\x07\x65nqueue\x18\x07 \x01(\x0b\x32).com.elarian.hera.proto.EnqueueCallActionH\x00\x12<\n\x07\x64\x65queue\x18\x08 \x01(\x0b\x32).com.elarian.hera.proto.DequeueCallActionH\x00\x12:\n\x06reject\x18\t \x01(\x0b\x32(.com.elarian.hera.proto.RejectCallActionH\x00\x12>\n\x08redirect\x18\n \x01(\x0b\x32*.com.elarian.hera.proto.RedirectCallActionH\x00\x42\x07\n\x05\x65ntry\"X\n\x1cVoiceCallDialplanMessageBody\x12\x38\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32\'.com.elarian.hera.proto.VoiceCallAction\"\x8d\x01\n\x12VoiceCallDialInput\x12\x1a\n\x12\x64\x65stination_number\x18\x01 \x01(\t\x12.\n\nstarted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xa1\x02\n\x13VoiceCallQueueInput\x12/\n\x0b\x65nqueued_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x64\x65queued_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x12\x64\x65queued_to_number\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12;\n\x15\x64\x65queued_to_sessionId\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0equeue_duration\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xf3\x03\n\x19VoiceCallInputMessageBody\x12\x41\n\tdirection\x18\x01 \x01(\x0e\x32..com.elarian.hera.proto.CustomerEventDirection\x12\x37\n\x06status\x18\x02 \x01(\x0e\x32\'.com.elarian.hera.proto.VoiceCallStatus\x12.\n\nstarted_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x42\n\x0changup_cause\x18\x04 \x01(\x0e\x32,.com.elarian.hera.proto.VoiceCallHangupCause\x12\x31\n\x0b\x64tmf_digits\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rrecording_url\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12=\n\tdial_data\x18\x07 \x01(\x0b\x32*.com.elarian.hera.proto.VoiceCallDialInput\x12?\n\nqueue_data\x18\x08 \x01(\x0b\x32+.com.elarian.hera.proto.VoiceCallQueueInput\"8\n\x13UssdMenuMessageBody\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x13\n\x0bis_terminal\x18\x02 \x01(\x08\"\xb9\x03\n\x13OutboundMessageBody\x12\x0e\n\x04text\x18\x01 \x01(\tH\x00\x12\x39\n\x05media\x18\x02 \x01(\x0b\x32(.com.elarian.hera.proto.MediaMessageBodyH\x00\x12?\n\x08location\x18\x03 \x01(\x0b\x32+.com.elarian.hera.proto.LocationMessageBodyH\x00\x12\x39\n\x05\x65mail\x18\x04 \x01(\x0b\x32(.com.elarian.hera.proto.EmailMessageBodyH\x00\x12?\n\x08template\x18\x05 \x01(\x0b\x32+.com.elarian.hera.proto.TemplateMessageBodyH\x00\x12\r\n\x03url\x18\x06 \x01(\tH\x00\x12\x45\n\x05voice\x18\x07 \x01(\x0b\x32\x34.com.elarian.hera.proto.VoiceCallDialplanMessageBodyH\x00\x12;\n\x04ussd\x18\x08 \x01(\x0b\x32+.com.elarian.hera.proto.UssdMenuMessageBodyH\x00\x42\x07\n\x05\x65ntry\"o\n\x19PromptMessageMenuItemBody\x12\x0e\n\x04text\x18\x02 \x01(\tH\x00\x12\x39\n\x05media\x18\x03 \x01(\x0b\x32(.com.elarian.hera.proto.MediaMessageBodyH\x00\x42\x07\n\x05\x65ntry\"\xd6\x02\n\x12InboundMessageBody\x12\x0e\n\x04text\x18\x01 \x01(\tH\x00\x12\x39\n\x05media\x18\x02 \x01(\x0b\x32(.com.elarian.hera.proto.MediaMessageBodyH\x00\x12?\n\x08location\x18\x03 \x01(\x0b\x32+.com.elarian.hera.proto.LocationMessageBodyH\x00\x12\x39\n\x05\x65mail\x18\x04 \x01(\x0b\x32(.com.elarian.hera.proto.EmailMessageBodyH\x00\x12\x42\n\x05voice\x18\x05 \x01(\x0b\x32\x31.com.elarian.hera.proto.VoiceCallInputMessageBodyH\x00\x12,\n\x04ussd\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x42\x07\n\x05\x65ntry\"\x9f\x01\n\x1aOutboundMessageReplyPrompt\x12@\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x30.com.elarian.hera.proto.PromptMessageReplyAction\x12?\n\x04menu\x18\x02 \x03(\x0b\x32\x31.com.elarian.hera.proto.PromptMessageMenuItemBody\"\x8d\x02\n\x0fOutboundMessage\x12\x39\n\x04\x62ody\x18\x01 \x01(\x0b\x32+.com.elarian.hera.proto.OutboundMessageBody\x12\x0e\n\x06labels\x18\x02 \x03(\t\x12\x32\n\x0cprovider_tag\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0breply_token\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12H\n\x0creply_prompt\x18\x05 \x01(\x0b\x32\x32.com.elarian.hera.proto.OutboundMessageReplyPrompt*\x8a\x02\n\x10MessagingChannel\x12!\n\x1dMESSAGING_CHANNEL_UNSPECIFIED\x10\x00\x12\x19\n\x15MESSAGING_CHANNEL_SMS\x10\x01\x12\x1b\n\x17MESSAGING_CHANNEL_VOICE\x10\x02\x12\x1a\n\x16MESSAGING_CHANNEL_USSD\x10\x03\x12\"\n\x1eMESSAGING_CHANNEL_FB_MESSENGER\x10\x04\x12\x1e\n\x1aMESSAGING_CHANNEL_TELEGRAM\x10\x05\x12\x1e\n\x1aMESSAGING_CHANNEL_WHATSAPP\x10\x06\x12\x1b\n\x17MESSAGING_CHANNEL_EMAIL\x10\x07*\x8a\x01\n\x16MessagingConsentUpdate\x12(\n$MESSAGING_CONSENT_UPDATE_UNSPECIFIED\x10\x00\x12\"\n\x1eMESSAGING_CONSENT_UPDATE_ALLOW\x10\x01\x12\"\n\x1eMESSAGING_CONSENT_UPDATE_BLOCK\x10\x02*\xe1\x02\n\x1cMessagingConsentUpdateStatus\x12/\n+MESSAGING_CONSENT_UPDATE_STATUS_UNSPECIFIED\x10\x00\x12*\n&MESSAGING_CONSENT_UPDATE_STATUS_QUEUED\x10\x64\x12.\n)MESSAGING_CONSENT_UPDATE_STATUS_COMPLETED\x10\xac\x02\x12;\n6MESSAGING_CONSENT_UPDATE_STATUS_INVALID_CHANNEL_NUMBER\x10\x91\x03\x12?\n:MESSAGING_CONSENT_UPDATE_STATUS_DECOMMISSIONED_CUSTOMER_ID\x10\x92\x03\x12\x36\n1MESSAGING_CONSENT_UPDATE_STATUS_APPLICATION_ERROR\x10\xf5\x03*\xd4\x01\n\x19MessagingSessionEndReason\x12,\n(MESSAGING_SESSION_END_REASON_UNSPECIFIED\x10\x00\x12\x30\n,MESSAGING_SESSION_END_REASON_NORMAL_CLEARING\x10\x64\x12,\n\'MESSAGING_SESSION_END_REASON_INACTIVITY\x10\xc8\x01\x12)\n$MESSAGING_SESSION_END_REASON_FAILURE\x10\xac\x02*\x97\x01\n\x0fMessageReaction\x12 \n\x1cMESSAGE_REACTION_UNSPECIFIED\x10\x00\x12\x1c\n\x18MESSAGE_REACTION_CLICKED\x10\x64\x12\"\n\x1dMESSAGE_REACTION_UNSUBSCRIBED\x10\xc8\x01\x12 \n\x1bMESSAGE_REACTION_COMPLAINED\x10\xc9\x01*\x91\x02\n\x18PromptMessageReplyAction\x12+\n\'PROMPT_MESSAGE_REPLY_ACTION_UNSPECIFIED\x10\x00\x12$\n PROMPT_MESSAGE_REPLY_ACTION_TEXT\x10\x01\x12,\n(PROMPT_MESSAGE_REPLY_ACTION_PHONE_NUMBER\x10\x02\x12%\n!PROMPT_MESSAGE_REPLY_ACTION_EMAIL\x10\x03\x12(\n$PROMPT_MESSAGE_REPLY_ACTION_LOCATION\x10\x04\x12#\n\x1fPROMPT_MESSAGE_REPLY_ACTION_URL\x10\x05*\x85\t\n\x15MessageDeliveryStatus\x12\'\n#MESSAGE_DELIVERY_STATUS_UNSPECIFIED\x10\x00\x12\"\n\x1eMESSAGE_DELIVERY_STATUS_QUEUED\x10\x64\x12 \n\x1cMESSAGE_DELIVERY_STATUS_SENT\x10\x65\x12&\n!MESSAGE_DELIVERY_STATUS_DELIVERED\x10\xac\x02\x12!\n\x1cMESSAGE_DELIVERY_STATUS_READ\x10\xad\x02\x12%\n MESSAGE_DELIVERY_STATUS_RECEIVED\x10\xae\x02\x12.\n)MESSAGE_DELIVERY_STATUS_SESSION_INITIATED\x10\xaf\x02\x12#\n\x1eMESSAGE_DELIVERY_STATUS_FAILED\x10\x90\x03\x12\'\n\"MESSAGE_DELIVERY_STATUS_NO_CONSENT\x10\x91\x03\x12*\n%MESSAGE_DELIVERY_STATUS_NO_CAPABILITY\x10\x92\x03\x12$\n\x1fMESSAGE_DELIVERY_STATUS_EXPIRED\x10\x93\x03\x12\x33\n.MESSAGE_DELIVERY_STATUS_NO_SESSION_IN_PROGRESS\x10\x94\x03\x12\x36\n1MESSAGE_DELIVERY_STATUS_OTHER_SESSION_IN_PROGRESS\x10\x95\x03\x12\x30\n+MESSAGE_DELIVERY_STATUS_INVALID_REPLY_TOKEN\x10\x96\x03\x12\x33\n.MESSAGE_DELIVERY_STATUS_INVALID_CHANNEL_NUMBER\x10\x97\x03\x12*\n%MESSAGE_DELIVERY_STATUS_NOT_SUPPORTED\x10\x98\x03\x12\x38\n3MESSAGE_DELIVERY_STATUS_INVALID_REPLY_TO_MESSAGE_ID\x10\x99\x03\x12\x30\n+MESSAGE_DELIVERY_STATUS_INVALID_CUSTOMER_ID\x10\x9a\x03\x12.\n)MESSAGE_DELIVERY_STATUS_DUPLICATE_REQUEST\x10\x9b\x03\x12*\n%MESSAGE_DELIVERY_STATUS_TAG_NOT_FOUND\x10\x9c\x03\x12\x36\n1MESSAGE_DELIVERY_STATUS_CUSTOMER_NUMBER_NOT_FOUND\x10\x9d\x03\x12\x36\n1MESSAGE_DELIVERY_STATUS_DECOMMISSIONED_CUSTOMERID\x10\x9e\x03\x12%\n MESSAGE_DELIVERY_STATUS_REJECTED\x10\x9f\x03\x12,\n\'MESSAGE_DELIVERY_STATUS_INVALID_REQUEST\x10\xa0\x03\x12.\n)MESSAGE_DELIVERY_STATUS_APPLICATION_ERROR\x10\xf5\x03*\xa5\x06\n\x0fVoiceCallStatus\x12!\n\x1dVOICE_CALL_STATUS_UNSPECIFIED\x10\x00\x12\x1c\n\x18VOICE_CALL_STATUS_QUEUED\x10\x64\x12\x1e\n\x1aVOICE_CALL_STATUS_ANSWERED\x10\x65\x12\x1d\n\x19VOICE_CALL_STATUS_RINGING\x10\x66\x12\x1d\n\x18VOICE_CALL_STATUS_ACTIVE\x10\xc8\x01\x12\x1e\n\x19VOICE_CALL_STATUS_DIALING\x10\xc9\x01\x12%\n VOICE_CALL_STATUS_DIAL_COMPLETED\x10\xca\x01\x12\x1e\n\x19VOICE_CALL_STATUS_BRIDGED\x10\xcb\x01\x12\x1f\n\x1aVOICE_CALL_STATUS_ENQUEUED\x10\xcc\x01\x12\x1f\n\x1aVOICE_CALL_STATUS_DEQUEUED\x10\xcd\x01\x12\"\n\x1dVOICE_CALL_STATUS_TRANSFERRED\x10\xce\x01\x12)\n$VOICE_CALL_STATUS_TRANSFER_COMPLETED\x10\xcf\x01\x12 \n\x1bVOICE_CALL_STATUS_COMPLETED\x10\xac\x02\x12*\n%VOICE_CALL_STATUS_INSUFFICIENT_CREDIT\x10\x90\x03\x12#\n\x1eVOICE_CALL_STATUS_NOT_ANSWERED\x10\x91\x03\x12+\n&VOICE_CALL_STATUS_INVALID_PHONE_NUMBER\x10\x92\x03\x12\x30\n+VOICE_CALL_STATUS_DESTINATION_NOT_SUPPORTED\x10\x93\x03\x12\x30\n+VOICE_CALL_STATUS_DECOMMISSIONED_CUSTOMERID\x10\x94\x03\x12\x1e\n\x19VOICE_CALL_STATUS_EXPIRED\x10\x95\x03\x12-\n(VOICE_CALL_STATUS_INVALID_CHANNEL_NUMBER\x10\x96\x03\x12(\n#VOICE_CALL_STATUS_APPLICATION_ERROR\x10\xf5\x03*\xc9\x05\n\x14VoiceCallHangupCause\x12\'\n#VOICE_CALL_HANGUP_CAUSE_UNSPECIFIED\x10\x00\x12.\n*VOICE_CALL_HANGUP_CAUSE_UNALLOCATED_NUMBER\x10\x01\x12%\n!VOICE_CALL_HANGUP_CAUSE_USER_BUSY\x10\x11\x12+\n\'VOICE_CALL_HANGUP_CAUSE_NORMAL_CLEARING\x10\x10\x12,\n(VOICE_CALL_HANGUP_CAUSE_NO_USER_RESPONSE\x10\x12\x12%\n!VOICE_CALL_HANGUP_CAUSE_NO_ANSWER\x10\x13\x12-\n)VOICE_CALL_HANGUP_CAUSE_SUBSCRIBER_ABSENT\x10\x14\x12)\n%VOICE_CALL_HANGUP_CAUSE_CALL_REJECTED\x10\x15\x12.\n*VOICE_CALL_HANGUP_CAUSE_NORMAL_UNSPECIFIED\x10\x1f\x12\x34\n0VOICE_CALL_HANGUP_CAUSE_NORMAL_TEMPORARY_FAILURE\x10)\x12/\n+VOICE_CALL_HANGUP_CAUSE_SERVICE_UNAVAILABLE\x10?\x12\x34\n0VOICE_CALL_HANGUP_CAUSE_RECOVERY_ON_TIMER_EXPIRE\x10\x66\x12.\n)VOICE_CALL_HANGUP_CAUSE_ORIGINATOR_CANCEL\x10\xe7\x03\x12&\n!VOICE_CALL_HANGUP_CAUSE_LOSE_RACE\x10\xf6\x03\x12\x30\n+VOICE_CALL_HANGUP_CAUSE_USER_NOT_REGISTERED\x10\xde\x04*y\n\x11TextToSpeechVoice\x12$\n TEXT_TO_SPEECH_VOICE_UNSPECIFIED\x10\x00\x12\x1d\n\x19TEXT_TO_SPEECH_VOICE_MALE\x10\x01\x12\x1f\n\x1bTEXT_TO_SPEECH_VOICE_FEMALE\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,common__model__pb2.DESCRIPTOR,])

_MESSAGINGCHANNEL = _descriptor.EnumDescriptor(
  name='MessagingChannel',
  full_name='com.elarian.hera.proto.MessagingChannel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MESSAGING_CHANNEL_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGING_CHANNEL_SMS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGING_CHANNEL_VOICE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGING_CHANNEL_USSD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGING_CHANNEL_FB_MESSENGER', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGING_CHANNEL_TELEGRAM', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGING_CHANNEL_WHATSAPP', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGING_CHANNEL_EMAIL', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5271,
  serialized_end=5537,
)
_sym_db.RegisterEnumDescriptor(_MESSAGINGCHANNEL)

MessagingChannel = enum_type_wrapper.EnumTypeWrapper(_MESSAGINGCHANNEL)
_MESSAGINGCONSENTUPDATE = _descriptor.EnumDescriptor(
  name='MessagingConsentUpdate',
  full_name='com.elarian.hera.proto.MessagingConsentUpdate',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MESSAGING_CONSENT_UPDATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGING_CONSENT_UPDATE_ALLOW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGING_CONSENT_UPDATE_BLOCK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5540,
  serialized_end=5678,
)
_sym_db.RegisterEnumDescriptor(_MESSAGINGCONSENTUPDATE)

MessagingConsentUpdate = enum_type_wrapper.EnumTypeWrapper(_MESSAGINGCONSENTUPDATE)
_MESSAGINGCONSENTUPDATESTATUS = _descriptor.EnumDescriptor(
  name='MessagingConsentUpdateStatus',
  full_name='com.elarian.hera.proto.MessagingConsentUpdateStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MESSAGING_CONSENT_UPDATE_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGING_CONSENT_UPDATE_STATUS_QUEUED', index=1, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGING_CONSENT_UPDATE_STATUS_COMPLETED', index=2, number=300,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGING_CONSENT_UPDATE_STATUS_INVALID_CHANNEL_NUMBER', index=3, number=401,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGING_CONSENT_UPDATE_STATUS_DECOMMISSIONED_CUSTOMER_ID', index=4, number=402,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGING_CONSENT_UPDATE_STATUS_APPLICATION_ERROR', index=5, number=501,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5681,
  serialized_end=6034,
)
_sym_db.RegisterEnumDescriptor(_MESSAGINGCONSENTUPDATESTATUS)

MessagingConsentUpdateStatus = enum_type_wrapper.EnumTypeWrapper(_MESSAGINGCONSENTUPDATESTATUS)
_MESSAGINGSESSIONENDREASON = _descriptor.EnumDescriptor(
  name='MessagingSessionEndReason',
  full_name='com.elarian.hera.proto.MessagingSessionEndReason',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MESSAGING_SESSION_END_REASON_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGING_SESSION_END_REASON_NORMAL_CLEARING', index=1, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGING_SESSION_END_REASON_INACTIVITY', index=2, number=200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGING_SESSION_END_REASON_FAILURE', index=3, number=300,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6037,
  serialized_end=6249,
)
_sym_db.RegisterEnumDescriptor(_MESSAGINGSESSIONENDREASON)

MessagingSessionEndReason = enum_type_wrapper.EnumTypeWrapper(_MESSAGINGSESSIONENDREASON)
_MESSAGEREACTION = _descriptor.EnumDescriptor(
  name='MessageReaction',
  full_name='com.elarian.hera.proto.MessageReaction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_REACTION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_REACTION_CLICKED', index=1, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_REACTION_UNSUBSCRIBED', index=2, number=200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_REACTION_COMPLAINED', index=3, number=201,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6252,
  serialized_end=6403,
)
_sym_db.RegisterEnumDescriptor(_MESSAGEREACTION)

MessageReaction = enum_type_wrapper.EnumTypeWrapper(_MESSAGEREACTION)
_PROMPTMESSAGEREPLYACTION = _descriptor.EnumDescriptor(
  name='PromptMessageReplyAction',
  full_name='com.elarian.hera.proto.PromptMessageReplyAction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PROMPT_MESSAGE_REPLY_ACTION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROMPT_MESSAGE_REPLY_ACTION_TEXT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROMPT_MESSAGE_REPLY_ACTION_PHONE_NUMBER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROMPT_MESSAGE_REPLY_ACTION_EMAIL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROMPT_MESSAGE_REPLY_ACTION_LOCATION', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROMPT_MESSAGE_REPLY_ACTION_URL', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6406,
  serialized_end=6679,
)
_sym_db.RegisterEnumDescriptor(_PROMPTMESSAGEREPLYACTION)

PromptMessageReplyAction = enum_type_wrapper.EnumTypeWrapper(_PROMPTMESSAGEREPLYACTION)
_MESSAGEDELIVERYSTATUS = _descriptor.EnumDescriptor(
  name='MessageDeliveryStatus',
  full_name='com.elarian.hera.proto.MessageDeliveryStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_QUEUED', index=1, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_SENT', index=2, number=101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_DELIVERED', index=3, number=300,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_READ', index=4, number=301,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_RECEIVED', index=5, number=302,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_SESSION_INITIATED', index=6, number=303,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_FAILED', index=7, number=400,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_NO_CONSENT', index=8, number=401,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_NO_CAPABILITY', index=9, number=402,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_EXPIRED', index=10, number=403,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_NO_SESSION_IN_PROGRESS', index=11, number=404,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_OTHER_SESSION_IN_PROGRESS', index=12, number=405,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_INVALID_REPLY_TOKEN', index=13, number=406,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_INVALID_CHANNEL_NUMBER', index=14, number=407,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_NOT_SUPPORTED', index=15, number=408,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_INVALID_REPLY_TO_MESSAGE_ID', index=16, number=409,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_INVALID_CUSTOMER_ID', index=17, number=410,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_DUPLICATE_REQUEST', index=18, number=411,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_TAG_NOT_FOUND', index=19, number=412,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_CUSTOMER_NUMBER_NOT_FOUND', index=20, number=413,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_DECOMMISSIONED_CUSTOMERID', index=21, number=414,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_REJECTED', index=22, number=415,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_INVALID_REQUEST', index=23, number=416,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_DELIVERY_STATUS_APPLICATION_ERROR', index=24, number=501,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6682,
  serialized_end=7839,
)
_sym_db.RegisterEnumDescriptor(_MESSAGEDELIVERYSTATUS)

MessageDeliveryStatus = enum_type_wrapper.EnumTypeWrapper(_MESSAGEDELIVERYSTATUS)
_VOICECALLSTATUS = _descriptor.EnumDescriptor(
  name='VoiceCallStatus',
  full_name='com.elarian.hera.proto.VoiceCallStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_STATUS_QUEUED', index=1, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_STATUS_ANSWERED', index=2, number=101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_STATUS_RINGING', index=3, number=102,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_STATUS_ACTIVE', index=4, number=200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_STATUS_DIALING', index=5, number=201,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_STATUS_DIAL_COMPLETED', index=6, number=202,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_STATUS_BRIDGED', index=7, number=203,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_STATUS_ENQUEUED', index=8, number=204,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_STATUS_DEQUEUED', index=9, number=205,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_STATUS_TRANSFERRED', index=10, number=206,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_STATUS_TRANSFER_COMPLETED', index=11, number=207,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_STATUS_COMPLETED', index=12, number=300,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_STATUS_INSUFFICIENT_CREDIT', index=13, number=400,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_STATUS_NOT_ANSWERED', index=14, number=401,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_STATUS_INVALID_PHONE_NUMBER', index=15, number=402,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_STATUS_DESTINATION_NOT_SUPPORTED', index=16, number=403,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_STATUS_DECOMMISSIONED_CUSTOMERID', index=17, number=404,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_STATUS_EXPIRED', index=18, number=405,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_STATUS_INVALID_CHANNEL_NUMBER', index=19, number=406,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_STATUS_APPLICATION_ERROR', index=20, number=501,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7842,
  serialized_end=8647,
)
_sym_db.RegisterEnumDescriptor(_VOICECALLSTATUS)

VoiceCallStatus = enum_type_wrapper.EnumTypeWrapper(_VOICECALLSTATUS)
_VOICECALLHANGUPCAUSE = _descriptor.EnumDescriptor(
  name='VoiceCallHangupCause',
  full_name='com.elarian.hera.proto.VoiceCallHangupCause',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_HANGUP_CAUSE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_HANGUP_CAUSE_UNALLOCATED_NUMBER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_HANGUP_CAUSE_USER_BUSY', index=2, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_HANGUP_CAUSE_NORMAL_CLEARING', index=3, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_HANGUP_CAUSE_NO_USER_RESPONSE', index=4, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_HANGUP_CAUSE_NO_ANSWER', index=5, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_HANGUP_CAUSE_SUBSCRIBER_ABSENT', index=6, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_HANGUP_CAUSE_CALL_REJECTED', index=7, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_HANGUP_CAUSE_NORMAL_UNSPECIFIED', index=8, number=31,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_HANGUP_CAUSE_NORMAL_TEMPORARY_FAILURE', index=9, number=41,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_HANGUP_CAUSE_SERVICE_UNAVAILABLE', index=10, number=63,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_HANGUP_CAUSE_RECOVERY_ON_TIMER_EXPIRE', index=11, number=102,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_HANGUP_CAUSE_ORIGINATOR_CANCEL', index=12, number=487,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_HANGUP_CAUSE_LOSE_RACE', index=13, number=502,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALL_HANGUP_CAUSE_USER_NOT_REGISTERED', index=14, number=606,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8650,
  serialized_end=9363,
)
_sym_db.RegisterEnumDescriptor(_VOICECALLHANGUPCAUSE)

VoiceCallHangupCause = enum_type_wrapper.EnumTypeWrapper(_VOICECALLHANGUPCAUSE)
_TEXTTOSPEECHVOICE = _descriptor.EnumDescriptor(
  name='TextToSpeechVoice',
  full_name='com.elarian.hera.proto.TextToSpeechVoice',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TEXT_TO_SPEECH_VOICE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEXT_TO_SPEECH_VOICE_MALE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEXT_TO_SPEECH_VOICE_FEMALE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9365,
  serialized_end=9486,
)
_sym_db.RegisterEnumDescriptor(_TEXTTOSPEECHVOICE)

TextToSpeechVoice = enum_type_wrapper.EnumTypeWrapper(_TEXTTOSPEECHVOICE)
MESSAGING_CHANNEL_UNSPECIFIED = 0
MESSAGING_CHANNEL_SMS = 1
MESSAGING_CHANNEL_VOICE = 2
MESSAGING_CHANNEL_USSD = 3
MESSAGING_CHANNEL_FB_MESSENGER = 4
MESSAGING_CHANNEL_TELEGRAM = 5
MESSAGING_CHANNEL_WHATSAPP = 6
MESSAGING_CHANNEL_EMAIL = 7
MESSAGING_CONSENT_UPDATE_UNSPECIFIED = 0
MESSAGING_CONSENT_UPDATE_ALLOW = 1
MESSAGING_CONSENT_UPDATE_BLOCK = 2
MESSAGING_CONSENT_UPDATE_STATUS_UNSPECIFIED = 0
MESSAGING_CONSENT_UPDATE_STATUS_QUEUED = 100
MESSAGING_CONSENT_UPDATE_STATUS_COMPLETED = 300
MESSAGING_CONSENT_UPDATE_STATUS_INVALID_CHANNEL_NUMBER = 401
MESSAGING_CONSENT_UPDATE_STATUS_DECOMMISSIONED_CUSTOMER_ID = 402
MESSAGING_CONSENT_UPDATE_STATUS_APPLICATION_ERROR = 501
MESSAGING_SESSION_END_REASON_UNSPECIFIED = 0
MESSAGING_SESSION_END_REASON_NORMAL_CLEARING = 100
MESSAGING_SESSION_END_REASON_INACTIVITY = 200
MESSAGING_SESSION_END_REASON_FAILURE = 300
MESSAGE_REACTION_UNSPECIFIED = 0
MESSAGE_REACTION_CLICKED = 100
MESSAGE_REACTION_UNSUBSCRIBED = 200
MESSAGE_REACTION_COMPLAINED = 201
PROMPT_MESSAGE_REPLY_ACTION_UNSPECIFIED = 0
PROMPT_MESSAGE_REPLY_ACTION_TEXT = 1
PROMPT_MESSAGE_REPLY_ACTION_PHONE_NUMBER = 2
PROMPT_MESSAGE_REPLY_ACTION_EMAIL = 3
PROMPT_MESSAGE_REPLY_ACTION_LOCATION = 4
PROMPT_MESSAGE_REPLY_ACTION_URL = 5
MESSAGE_DELIVERY_STATUS_UNSPECIFIED = 0
MESSAGE_DELIVERY_STATUS_QUEUED = 100
MESSAGE_DELIVERY_STATUS_SENT = 101
MESSAGE_DELIVERY_STATUS_DELIVERED = 300
MESSAGE_DELIVERY_STATUS_READ = 301
MESSAGE_DELIVERY_STATUS_RECEIVED = 302
MESSAGE_DELIVERY_STATUS_SESSION_INITIATED = 303
MESSAGE_DELIVERY_STATUS_FAILED = 400
MESSAGE_DELIVERY_STATUS_NO_CONSENT = 401
MESSAGE_DELIVERY_STATUS_NO_CAPABILITY = 402
MESSAGE_DELIVERY_STATUS_EXPIRED = 403
MESSAGE_DELIVERY_STATUS_NO_SESSION_IN_PROGRESS = 404
MESSAGE_DELIVERY_STATUS_OTHER_SESSION_IN_PROGRESS = 405
MESSAGE_DELIVERY_STATUS_INVALID_REPLY_TOKEN = 406
MESSAGE_DELIVERY_STATUS_INVALID_CHANNEL_NUMBER = 407
MESSAGE_DELIVERY_STATUS_NOT_SUPPORTED = 408
MESSAGE_DELIVERY_STATUS_INVALID_REPLY_TO_MESSAGE_ID = 409
MESSAGE_DELIVERY_STATUS_INVALID_CUSTOMER_ID = 410
MESSAGE_DELIVERY_STATUS_DUPLICATE_REQUEST = 411
MESSAGE_DELIVERY_STATUS_TAG_NOT_FOUND = 412
MESSAGE_DELIVERY_STATUS_CUSTOMER_NUMBER_NOT_FOUND = 413
MESSAGE_DELIVERY_STATUS_DECOMMISSIONED_CUSTOMERID = 414
MESSAGE_DELIVERY_STATUS_REJECTED = 415
MESSAGE_DELIVERY_STATUS_INVALID_REQUEST = 416
MESSAGE_DELIVERY_STATUS_APPLICATION_ERROR = 501
VOICE_CALL_STATUS_UNSPECIFIED = 0
VOICE_CALL_STATUS_QUEUED = 100
VOICE_CALL_STATUS_ANSWERED = 101
VOICE_CALL_STATUS_RINGING = 102
VOICE_CALL_STATUS_ACTIVE = 200
VOICE_CALL_STATUS_DIALING = 201
VOICE_CALL_STATUS_DIAL_COMPLETED = 202
VOICE_CALL_STATUS_BRIDGED = 203
VOICE_CALL_STATUS_ENQUEUED = 204
VOICE_CALL_STATUS_DEQUEUED = 205
VOICE_CALL_STATUS_TRANSFERRED = 206
VOICE_CALL_STATUS_TRANSFER_COMPLETED = 207
VOICE_CALL_STATUS_COMPLETED = 300
VOICE_CALL_STATUS_INSUFFICIENT_CREDIT = 400
VOICE_CALL_STATUS_NOT_ANSWERED = 401
VOICE_CALL_STATUS_INVALID_PHONE_NUMBER = 402
VOICE_CALL_STATUS_DESTINATION_NOT_SUPPORTED = 403
VOICE_CALL_STATUS_DECOMMISSIONED_CUSTOMERID = 404
VOICE_CALL_STATUS_EXPIRED = 405
VOICE_CALL_STATUS_INVALID_CHANNEL_NUMBER = 406
VOICE_CALL_STATUS_APPLICATION_ERROR = 501
VOICE_CALL_HANGUP_CAUSE_UNSPECIFIED = 0
VOICE_CALL_HANGUP_CAUSE_UNALLOCATED_NUMBER = 1
VOICE_CALL_HANGUP_CAUSE_USER_BUSY = 17
VOICE_CALL_HANGUP_CAUSE_NORMAL_CLEARING = 16
VOICE_CALL_HANGUP_CAUSE_NO_USER_RESPONSE = 18
VOICE_CALL_HANGUP_CAUSE_NO_ANSWER = 19
VOICE_CALL_HANGUP_CAUSE_SUBSCRIBER_ABSENT = 20
VOICE_CALL_HANGUP_CAUSE_CALL_REJECTED = 21
VOICE_CALL_HANGUP_CAUSE_NORMAL_UNSPECIFIED = 31
VOICE_CALL_HANGUP_CAUSE_NORMAL_TEMPORARY_FAILURE = 41
VOICE_CALL_HANGUP_CAUSE_SERVICE_UNAVAILABLE = 63
VOICE_CALL_HANGUP_CAUSE_RECOVERY_ON_TIMER_EXPIRE = 102
VOICE_CALL_HANGUP_CAUSE_ORIGINATOR_CANCEL = 487
VOICE_CALL_HANGUP_CAUSE_LOSE_RACE = 502
VOICE_CALL_HANGUP_CAUSE_USER_NOT_REGISTERED = 606
TEXT_TO_SPEECH_VOICE_UNSPECIFIED = 0
TEXT_TO_SPEECH_VOICE_MALE = 1
TEXT_TO_SPEECH_VOICE_FEMALE = 2



_MESSAGINGCHANNELNUMBER = _descriptor.Descriptor(
  name='MessagingChannelNumber',
  full_name='com.elarian.hera.proto.MessagingChannelNumber',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='com.elarian.hera.proto.MessagingChannelNumber.channel', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number', full_name='com.elarian.hera.proto.MessagingChannelNumber.number', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=265,
)


_MEDIAMESSAGEBODY = _descriptor.Descriptor(
  name='MediaMessageBody',
  full_name='com.elarian.hera.proto.MediaMessageBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='com.elarian.hera.proto.MediaMessageBody.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='media', full_name='com.elarian.hera.proto.MediaMessageBody.media', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=267,
  serialized_end=348,
)


_LOCATIONMESSAGEBODY = _descriptor.Descriptor(
  name='LocationMessageBody',
  full_name='com.elarian.hera.proto.LocationMessageBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='latitude', full_name='com.elarian.hera.proto.LocationMessageBody.latitude', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='com.elarian.hera.proto.LocationMessageBody.longitude', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='com.elarian.hera.proto.LocationMessageBody.label', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='com.elarian.hera.proto.LocationMessageBody.address', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=351,
  serialized_end=501,
)


_EMAILMESSAGEBODY = _descriptor.Descriptor(
  name='EmailMessageBody',
  full_name='com.elarian.hera.proto.EmailMessageBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='com.elarian.hera.proto.EmailMessageBody.subject', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body_plain', full_name='com.elarian.hera.proto.EmailMessageBody.body_plain', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body_html', full_name='com.elarian.hera.proto.EmailMessageBody.body_html', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cc_list', full_name='com.elarian.hera.proto.EmailMessageBody.cc_list', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcc_list', full_name='com.elarian.hera.proto.EmailMessageBody.bcc_list', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attachments', full_name='com.elarian.hera.proto.EmailMessageBody.attachments', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=504,
  serialized_end=634,
)


_TEMPLATEMESSAGEBODY_PARAMSENTRY = _descriptor.Descriptor(
  name='ParamsEntry',
  full_name='com.elarian.hera.proto.TemplateMessageBody.ParamsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.elarian.hera.proto.TemplateMessageBody.ParamsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.elarian.hera.proto.TemplateMessageBody.ParamsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=745,
  serialized_end=790,
)

_TEMPLATEMESSAGEBODY = _descriptor.Descriptor(
  name='TemplateMessageBody',
  full_name='com.elarian.hera.proto.TemplateMessageBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='com.elarian.hera.proto.TemplateMessageBody.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='com.elarian.hera.proto.TemplateMessageBody.params', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TEMPLATEMESSAGEBODY_PARAMSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=637,
  serialized_end=790,
)


_SAYCALLACTION = _descriptor.Descriptor(
  name='SayCallAction',
  full_name='com.elarian.hera.proto.SayCallAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='com.elarian.hera.proto.SayCallAction.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voice', full_name='com.elarian.hera.proto.SayCallAction.voice', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='play_beep', full_name='com.elarian.hera.proto.SayCallAction.play_beep', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=792,
  serialized_end=898,
)


_PLAYCALLACTION = _descriptor.Descriptor(
  name='PlayCallAction',
  full_name='com.elarian.hera.proto.PlayCallAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='com.elarian.hera.proto.PlayCallAction.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=900,
  serialized_end=929,
)


_GETDIGITSCALLACTION = _descriptor.Descriptor(
  name='GetDigitsCallAction',
  full_name='com.elarian.hera.proto.GetDigitsCallAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='say', full_name='com.elarian.hera.proto.GetDigitsCallAction.say', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='play', full_name='com.elarian.hera.proto.GetDigitsCallAction.play', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='com.elarian.hera.proto.GetDigitsCallAction.timeout', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='finish_on_key', full_name='com.elarian.hera.proto.GetDigitsCallAction.finish_on_key', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_digits', full_name='com.elarian.hera.proto.GetDigitsCallAction.num_digits', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='prompt', full_name='com.elarian.hera.proto.GetDigitsCallAction.prompt',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=932,
  serialized_end=1219,
)


_GETRECORDINGCALLACTION = _descriptor.Descriptor(
  name='GetRecordingCallAction',
  full_name='com.elarian.hera.proto.GetRecordingCallAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='say', full_name='com.elarian.hera.proto.GetRecordingCallAction.say', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='play', full_name='com.elarian.hera.proto.GetRecordingCallAction.play', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='com.elarian.hera.proto.GetRecordingCallAction.timeout', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_length', full_name='com.elarian.hera.proto.GetRecordingCallAction.max_length', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='finish_on_key', full_name='com.elarian.hera.proto.GetRecordingCallAction.finish_on_key', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='play_beep', full_name='com.elarian.hera.proto.GetRecordingCallAction.play_beep', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trim_silence', full_name='com.elarian.hera.proto.GetRecordingCallAction.trim_silence', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='prompt', full_name='com.elarian.hera.proto.GetRecordingCallAction.prompt',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1222,
  serialized_end=1551,
)


_RECORDSESSIONCALLACTION = _descriptor.Descriptor(
  name='RecordSessionCallAction',
  full_name='com.elarian.hera.proto.RecordSessionCallAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1553,
  serialized_end=1578,
)


_DIALCALLACTION = _descriptor.Descriptor(
  name='DialCallAction',
  full_name='com.elarian.hera.proto.DialCallAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_numbers', full_name='com.elarian.hera.proto.DialCallAction.customer_numbers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='record', full_name='com.elarian.hera.proto.DialCallAction.record', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sequential', full_name='com.elarian.hera.proto.DialCallAction.sequential', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ringback_tone', full_name='com.elarian.hera.proto.DialCallAction.ringback_tone', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='caller_id', full_name='com.elarian.hera.proto.DialCallAction.caller_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_duration', full_name='com.elarian.hera.proto.DialCallAction.max_duration', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1581,
  serialized_end=1852,
)


_ENQUEUECALLACTION = _descriptor.Descriptor(
  name='EnqueueCallAction',
  full_name='com.elarian.hera.proto.EnqueueCallAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hold_music', full_name='com.elarian.hera.proto.EnqueueCallAction.hold_music', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queue_name', full_name='com.elarian.hera.proto.EnqueueCallAction.queue_name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1854,
  serialized_end=1973,
)


_DEQUEUECALLACTION = _descriptor.Descriptor(
  name='DequeueCallAction',
  full_name='com.elarian.hera.proto.DequeueCallAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.DequeueCallAction.channel_number', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='record', full_name='com.elarian.hera.proto.DequeueCallAction.record', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queue_name', full_name='com.elarian.hera.proto.DequeueCallAction.queue_name', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1976,
  serialized_end=2133,
)


_REJECTCALLACTION = _descriptor.Descriptor(
  name='RejectCallAction',
  full_name='com.elarian.hera.proto.RejectCallAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2135,
  serialized_end=2153,
)


_REDIRECTCALLACTION = _descriptor.Descriptor(
  name='RedirectCallAction',
  full_name='com.elarian.hera.proto.RedirectCallAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='com.elarian.hera.proto.RedirectCallAction.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2155,
  serialized_end=2188,
)


_VOICECALLACTION = _descriptor.Descriptor(
  name='VoiceCallAction',
  full_name='com.elarian.hera.proto.VoiceCallAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='say', full_name='com.elarian.hera.proto.VoiceCallAction.say', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='play', full_name='com.elarian.hera.proto.VoiceCallAction.play', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='get_digits', full_name='com.elarian.hera.proto.VoiceCallAction.get_digits', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dial', full_name='com.elarian.hera.proto.VoiceCallAction.dial', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='record_session', full_name='com.elarian.hera.proto.VoiceCallAction.record_session', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='get_recording', full_name='com.elarian.hera.proto.VoiceCallAction.get_recording', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enqueue', full_name='com.elarian.hera.proto.VoiceCallAction.enqueue', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dequeue', full_name='com.elarian.hera.proto.VoiceCallAction.dequeue', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reject', full_name='com.elarian.hera.proto.VoiceCallAction.reject', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirect', full_name='com.elarian.hera.proto.VoiceCallAction.redirect', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='entry', full_name='com.elarian.hera.proto.VoiceCallAction.entry',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2191,
  serialized_end=2846,
)


_VOICECALLDIALPLANMESSAGEBODY = _descriptor.Descriptor(
  name='VoiceCallDialplanMessageBody',
  full_name='com.elarian.hera.proto.VoiceCallDialplanMessageBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actions', full_name='com.elarian.hera.proto.VoiceCallDialplanMessageBody.actions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2848,
  serialized_end=2936,
)


_VOICECALLDIALINPUT = _descriptor.Descriptor(
  name='VoiceCallDialInput',
  full_name='com.elarian.hera.proto.VoiceCallDialInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='destination_number', full_name='com.elarian.hera.proto.VoiceCallDialInput.destination_number', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started_at', full_name='com.elarian.hera.proto.VoiceCallDialInput.started_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='com.elarian.hera.proto.VoiceCallDialInput.duration', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2939,
  serialized_end=3080,
)


_VOICECALLQUEUEINPUT = _descriptor.Descriptor(
  name='VoiceCallQueueInput',
  full_name='com.elarian.hera.proto.VoiceCallQueueInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enqueued_at', full_name='com.elarian.hera.proto.VoiceCallQueueInput.enqueued_at', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dequeued_at', full_name='com.elarian.hera.proto.VoiceCallQueueInput.dequeued_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dequeued_to_number', full_name='com.elarian.hera.proto.VoiceCallQueueInput.dequeued_to_number', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dequeued_to_sessionId', full_name='com.elarian.hera.proto.VoiceCallQueueInput.dequeued_to_sessionId', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queue_duration', full_name='com.elarian.hera.proto.VoiceCallQueueInput.queue_duration', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3083,
  serialized_end=3372,
)


_VOICECALLINPUTMESSAGEBODY = _descriptor.Descriptor(
  name='VoiceCallInputMessageBody',
  full_name='com.elarian.hera.proto.VoiceCallInputMessageBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='direction', full_name='com.elarian.hera.proto.VoiceCallInputMessageBody.direction', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.VoiceCallInputMessageBody.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started_at', full_name='com.elarian.hera.proto.VoiceCallInputMessageBody.started_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hangup_cause', full_name='com.elarian.hera.proto.VoiceCallInputMessageBody.hangup_cause', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dtmf_digits', full_name='com.elarian.hera.proto.VoiceCallInputMessageBody.dtmf_digits', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recording_url', full_name='com.elarian.hera.proto.VoiceCallInputMessageBody.recording_url', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dial_data', full_name='com.elarian.hera.proto.VoiceCallInputMessageBody.dial_data', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queue_data', full_name='com.elarian.hera.proto.VoiceCallInputMessageBody.queue_data', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3375,
  serialized_end=3874,
)


_USSDMENUMESSAGEBODY = _descriptor.Descriptor(
  name='UssdMenuMessageBody',
  full_name='com.elarian.hera.proto.UssdMenuMessageBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='com.elarian.hera.proto.UssdMenuMessageBody.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_terminal', full_name='com.elarian.hera.proto.UssdMenuMessageBody.is_terminal', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3876,
  serialized_end=3932,
)


_OUTBOUNDMESSAGEBODY = _descriptor.Descriptor(
  name='OutboundMessageBody',
  full_name='com.elarian.hera.proto.OutboundMessageBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='com.elarian.hera.proto.OutboundMessageBody.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='media', full_name='com.elarian.hera.proto.OutboundMessageBody.media', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='com.elarian.hera.proto.OutboundMessageBody.location', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email', full_name='com.elarian.hera.proto.OutboundMessageBody.email', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='template', full_name='com.elarian.hera.proto.OutboundMessageBody.template', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='com.elarian.hera.proto.OutboundMessageBody.url', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voice', full_name='com.elarian.hera.proto.OutboundMessageBody.voice', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ussd', full_name='com.elarian.hera.proto.OutboundMessageBody.ussd', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='entry', full_name='com.elarian.hera.proto.OutboundMessageBody.entry',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3935,
  serialized_end=4376,
)


_PROMPTMESSAGEMENUITEMBODY = _descriptor.Descriptor(
  name='PromptMessageMenuItemBody',
  full_name='com.elarian.hera.proto.PromptMessageMenuItemBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='com.elarian.hera.proto.PromptMessageMenuItemBody.text', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='media', full_name='com.elarian.hera.proto.PromptMessageMenuItemBody.media', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='entry', full_name='com.elarian.hera.proto.PromptMessageMenuItemBody.entry',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4378,
  serialized_end=4489,
)


_INBOUNDMESSAGEBODY = _descriptor.Descriptor(
  name='InboundMessageBody',
  full_name='com.elarian.hera.proto.InboundMessageBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='com.elarian.hera.proto.InboundMessageBody.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='media', full_name='com.elarian.hera.proto.InboundMessageBody.media', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='com.elarian.hera.proto.InboundMessageBody.location', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email', full_name='com.elarian.hera.proto.InboundMessageBody.email', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voice', full_name='com.elarian.hera.proto.InboundMessageBody.voice', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ussd', full_name='com.elarian.hera.proto.InboundMessageBody.ussd', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='entry', full_name='com.elarian.hera.proto.InboundMessageBody.entry',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4492,
  serialized_end=4834,
)


_OUTBOUNDMESSAGEREPLYPROMPT = _descriptor.Descriptor(
  name='OutboundMessageReplyPrompt',
  full_name='com.elarian.hera.proto.OutboundMessageReplyPrompt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='com.elarian.hera.proto.OutboundMessageReplyPrompt.action', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='menu', full_name='com.elarian.hera.proto.OutboundMessageReplyPrompt.menu', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4837,
  serialized_end=4996,
)


_OUTBOUNDMESSAGE = _descriptor.Descriptor(
  name='OutboundMessage',
  full_name='com.elarian.hera.proto.OutboundMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='body', full_name='com.elarian.hera.proto.OutboundMessage.body', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='com.elarian.hera.proto.OutboundMessage.labels', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider_tag', full_name='com.elarian.hera.proto.OutboundMessage.provider_tag', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reply_token', full_name='com.elarian.hera.proto.OutboundMessage.reply_token', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reply_prompt', full_name='com.elarian.hera.proto.OutboundMessage.reply_prompt', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4999,
  serialized_end=5268,
)

_MESSAGINGCHANNELNUMBER.fields_by_name['channel'].enum_type = _MESSAGINGCHANNEL
_MEDIAMESSAGEBODY.fields_by_name['media'].enum_type = common__model__pb2._MEDIATYPE
_LOCATIONMESSAGEBODY.fields_by_name['label'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LOCATIONMESSAGEBODY.fields_by_name['address'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TEMPLATEMESSAGEBODY_PARAMSENTRY.containing_type = _TEMPLATEMESSAGEBODY
_TEMPLATEMESSAGEBODY.fields_by_name['params'].message_type = _TEMPLATEMESSAGEBODY_PARAMSENTRY
_SAYCALLACTION.fields_by_name['voice'].enum_type = _TEXTTOSPEECHVOICE
_GETDIGITSCALLACTION.fields_by_name['say'].message_type = _SAYCALLACTION
_GETDIGITSCALLACTION.fields_by_name['play'].message_type = _PLAYCALLACTION
_GETDIGITSCALLACTION.fields_by_name['timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_GETDIGITSCALLACTION.fields_by_name['finish_on_key'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GETDIGITSCALLACTION.fields_by_name['num_digits'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_GETDIGITSCALLACTION.oneofs_by_name['prompt'].fields.append(
  _GETDIGITSCALLACTION.fields_by_name['say'])
_GETDIGITSCALLACTION.fields_by_name['say'].containing_oneof = _GETDIGITSCALLACTION.oneofs_by_name['prompt']
_GETDIGITSCALLACTION.oneofs_by_name['prompt'].fields.append(
  _GETDIGITSCALLACTION.fields_by_name['play'])
_GETDIGITSCALLACTION.fields_by_name['play'].containing_oneof = _GETDIGITSCALLACTION.oneofs_by_name['prompt']
_GETRECORDINGCALLACTION.fields_by_name['say'].message_type = _SAYCALLACTION
_GETRECORDINGCALLACTION.fields_by_name['play'].message_type = _PLAYCALLACTION
_GETRECORDINGCALLACTION.fields_by_name['timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_GETRECORDINGCALLACTION.fields_by_name['max_length'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_GETRECORDINGCALLACTION.fields_by_name['finish_on_key'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GETRECORDINGCALLACTION.oneofs_by_name['prompt'].fields.append(
  _GETRECORDINGCALLACTION.fields_by_name['say'])
_GETRECORDINGCALLACTION.fields_by_name['say'].containing_oneof = _GETRECORDINGCALLACTION.oneofs_by_name['prompt']
_GETRECORDINGCALLACTION.oneofs_by_name['prompt'].fields.append(
  _GETRECORDINGCALLACTION.fields_by_name['play'])
_GETRECORDINGCALLACTION.fields_by_name['play'].containing_oneof = _GETRECORDINGCALLACTION.oneofs_by_name['prompt']
_DIALCALLACTION.fields_by_name['customer_numbers'].message_type = common__model__pb2._CUSTOMERNUMBER
_DIALCALLACTION.fields_by_name['ringback_tone'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DIALCALLACTION.fields_by_name['caller_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DIALCALLACTION.fields_by_name['max_duration'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_ENQUEUECALLACTION.fields_by_name['hold_music'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ENQUEUECALLACTION.fields_by_name['queue_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DEQUEUECALLACTION.fields_by_name['channel_number'].message_type = _MESSAGINGCHANNELNUMBER
_DEQUEUECALLACTION.fields_by_name['queue_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_VOICECALLACTION.fields_by_name['say'].message_type = _SAYCALLACTION
_VOICECALLACTION.fields_by_name['play'].message_type = _PLAYCALLACTION
_VOICECALLACTION.fields_by_name['get_digits'].message_type = _GETDIGITSCALLACTION
_VOICECALLACTION.fields_by_name['dial'].message_type = _DIALCALLACTION
_VOICECALLACTION.fields_by_name['record_session'].message_type = _RECORDSESSIONCALLACTION
_VOICECALLACTION.fields_by_name['get_recording'].message_type = _GETRECORDINGCALLACTION
_VOICECALLACTION.fields_by_name['enqueue'].message_type = _ENQUEUECALLACTION
_VOICECALLACTION.fields_by_name['dequeue'].message_type = _DEQUEUECALLACTION
_VOICECALLACTION.fields_by_name['reject'].message_type = _REJECTCALLACTION
_VOICECALLACTION.fields_by_name['redirect'].message_type = _REDIRECTCALLACTION
_VOICECALLACTION.oneofs_by_name['entry'].fields.append(
  _VOICECALLACTION.fields_by_name['say'])
_VOICECALLACTION.fields_by_name['say'].containing_oneof = _VOICECALLACTION.oneofs_by_name['entry']
_VOICECALLACTION.oneofs_by_name['entry'].fields.append(
  _VOICECALLACTION.fields_by_name['play'])
_VOICECALLACTION.fields_by_name['play'].containing_oneof = _VOICECALLACTION.oneofs_by_name['entry']
_VOICECALLACTION.oneofs_by_name['entry'].fields.append(
  _VOICECALLACTION.fields_by_name['get_digits'])
_VOICECALLACTION.fields_by_name['get_digits'].containing_oneof = _VOICECALLACTION.oneofs_by_name['entry']
_VOICECALLACTION.oneofs_by_name['entry'].fields.append(
  _VOICECALLACTION.fields_by_name['dial'])
_VOICECALLACTION.fields_by_name['dial'].containing_oneof = _VOICECALLACTION.oneofs_by_name['entry']
_VOICECALLACTION.oneofs_by_name['entry'].fields.append(
  _VOICECALLACTION.fields_by_name['record_session'])
_VOICECALLACTION.fields_by_name['record_session'].containing_oneof = _VOICECALLACTION.oneofs_by_name['entry']
_VOICECALLACTION.oneofs_by_name['entry'].fields.append(
  _VOICECALLACTION.fields_by_name['get_recording'])
_VOICECALLACTION.fields_by_name['get_recording'].containing_oneof = _VOICECALLACTION.oneofs_by_name['entry']
_VOICECALLACTION.oneofs_by_name['entry'].fields.append(
  _VOICECALLACTION.fields_by_name['enqueue'])
_VOICECALLACTION.fields_by_name['enqueue'].containing_oneof = _VOICECALLACTION.oneofs_by_name['entry']
_VOICECALLACTION.oneofs_by_name['entry'].fields.append(
  _VOICECALLACTION.fields_by_name['dequeue'])
_VOICECALLACTION.fields_by_name['dequeue'].containing_oneof = _VOICECALLACTION.oneofs_by_name['entry']
_VOICECALLACTION.oneofs_by_name['entry'].fields.append(
  _VOICECALLACTION.fields_by_name['reject'])
_VOICECALLACTION.fields_by_name['reject'].containing_oneof = _VOICECALLACTION.oneofs_by_name['entry']
_VOICECALLACTION.oneofs_by_name['entry'].fields.append(
  _VOICECALLACTION.fields_by_name['redirect'])
_VOICECALLACTION.fields_by_name['redirect'].containing_oneof = _VOICECALLACTION.oneofs_by_name['entry']
_VOICECALLDIALPLANMESSAGEBODY.fields_by_name['actions'].message_type = _VOICECALLACTION
_VOICECALLDIALINPUT.fields_by_name['started_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_VOICECALLDIALINPUT.fields_by_name['duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_VOICECALLQUEUEINPUT.fields_by_name['enqueued_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_VOICECALLQUEUEINPUT.fields_by_name['dequeued_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_VOICECALLQUEUEINPUT.fields_by_name['dequeued_to_number'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_VOICECALLQUEUEINPUT.fields_by_name['dequeued_to_sessionId'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_VOICECALLQUEUEINPUT.fields_by_name['queue_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_VOICECALLINPUTMESSAGEBODY.fields_by_name['direction'].enum_type = common__model__pb2._CUSTOMEREVENTDIRECTION
_VOICECALLINPUTMESSAGEBODY.fields_by_name['status'].enum_type = _VOICECALLSTATUS
_VOICECALLINPUTMESSAGEBODY.fields_by_name['started_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_VOICECALLINPUTMESSAGEBODY.fields_by_name['hangup_cause'].enum_type = _VOICECALLHANGUPCAUSE
_VOICECALLINPUTMESSAGEBODY.fields_by_name['dtmf_digits'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_VOICECALLINPUTMESSAGEBODY.fields_by_name['recording_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_VOICECALLINPUTMESSAGEBODY.fields_by_name['dial_data'].message_type = _VOICECALLDIALINPUT
_VOICECALLINPUTMESSAGEBODY.fields_by_name['queue_data'].message_type = _VOICECALLQUEUEINPUT
_OUTBOUNDMESSAGEBODY.fields_by_name['media'].message_type = _MEDIAMESSAGEBODY
_OUTBOUNDMESSAGEBODY.fields_by_name['location'].message_type = _LOCATIONMESSAGEBODY
_OUTBOUNDMESSAGEBODY.fields_by_name['email'].message_type = _EMAILMESSAGEBODY
_OUTBOUNDMESSAGEBODY.fields_by_name['template'].message_type = _TEMPLATEMESSAGEBODY
_OUTBOUNDMESSAGEBODY.fields_by_name['voice'].message_type = _VOICECALLDIALPLANMESSAGEBODY
_OUTBOUNDMESSAGEBODY.fields_by_name['ussd'].message_type = _USSDMENUMESSAGEBODY
_OUTBOUNDMESSAGEBODY.oneofs_by_name['entry'].fields.append(
  _OUTBOUNDMESSAGEBODY.fields_by_name['text'])
_OUTBOUNDMESSAGEBODY.fields_by_name['text'].containing_oneof = _OUTBOUNDMESSAGEBODY.oneofs_by_name['entry']
_OUTBOUNDMESSAGEBODY.oneofs_by_name['entry'].fields.append(
  _OUTBOUNDMESSAGEBODY.fields_by_name['media'])
_OUTBOUNDMESSAGEBODY.fields_by_name['media'].containing_oneof = _OUTBOUNDMESSAGEBODY.oneofs_by_name['entry']
_OUTBOUNDMESSAGEBODY.oneofs_by_name['entry'].fields.append(
  _OUTBOUNDMESSAGEBODY.fields_by_name['location'])
_OUTBOUNDMESSAGEBODY.fields_by_name['location'].containing_oneof = _OUTBOUNDMESSAGEBODY.oneofs_by_name['entry']
_OUTBOUNDMESSAGEBODY.oneofs_by_name['entry'].fields.append(
  _OUTBOUNDMESSAGEBODY.fields_by_name['email'])
_OUTBOUNDMESSAGEBODY.fields_by_name['email'].containing_oneof = _OUTBOUNDMESSAGEBODY.oneofs_by_name['entry']
_OUTBOUNDMESSAGEBODY.oneofs_by_name['entry'].fields.append(
  _OUTBOUNDMESSAGEBODY.fields_by_name['template'])
_OUTBOUNDMESSAGEBODY.fields_by_name['template'].containing_oneof = _OUTBOUNDMESSAGEBODY.oneofs_by_name['entry']
_OUTBOUNDMESSAGEBODY.oneofs_by_name['entry'].fields.append(
  _OUTBOUNDMESSAGEBODY.fields_by_name['url'])
_OUTBOUNDMESSAGEBODY.fields_by_name['url'].containing_oneof = _OUTBOUNDMESSAGEBODY.oneofs_by_name['entry']
_OUTBOUNDMESSAGEBODY.oneofs_by_name['entry'].fields.append(
  _OUTBOUNDMESSAGEBODY.fields_by_name['voice'])
_OUTBOUNDMESSAGEBODY.fields_by_name['voice'].containing_oneof = _OUTBOUNDMESSAGEBODY.oneofs_by_name['entry']
_OUTBOUNDMESSAGEBODY.oneofs_by_name['entry'].fields.append(
  _OUTBOUNDMESSAGEBODY.fields_by_name['ussd'])
_OUTBOUNDMESSAGEBODY.fields_by_name['ussd'].containing_oneof = _OUTBOUNDMESSAGEBODY.oneofs_by_name['entry']
_PROMPTMESSAGEMENUITEMBODY.fields_by_name['media'].message_type = _MEDIAMESSAGEBODY
_PROMPTMESSAGEMENUITEMBODY.oneofs_by_name['entry'].fields.append(
  _PROMPTMESSAGEMENUITEMBODY.fields_by_name['text'])
_PROMPTMESSAGEMENUITEMBODY.fields_by_name['text'].containing_oneof = _PROMPTMESSAGEMENUITEMBODY.oneofs_by_name['entry']
_PROMPTMESSAGEMENUITEMBODY.oneofs_by_name['entry'].fields.append(
  _PROMPTMESSAGEMENUITEMBODY.fields_by_name['media'])
_PROMPTMESSAGEMENUITEMBODY.fields_by_name['media'].containing_oneof = _PROMPTMESSAGEMENUITEMBODY.oneofs_by_name['entry']
_INBOUNDMESSAGEBODY.fields_by_name['media'].message_type = _MEDIAMESSAGEBODY
_INBOUNDMESSAGEBODY.fields_by_name['location'].message_type = _LOCATIONMESSAGEBODY
_INBOUNDMESSAGEBODY.fields_by_name['email'].message_type = _EMAILMESSAGEBODY
_INBOUNDMESSAGEBODY.fields_by_name['voice'].message_type = _VOICECALLINPUTMESSAGEBODY
_INBOUNDMESSAGEBODY.fields_by_name['ussd'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INBOUNDMESSAGEBODY.oneofs_by_name['entry'].fields.append(
  _INBOUNDMESSAGEBODY.fields_by_name['text'])
_INBOUNDMESSAGEBODY.fields_by_name['text'].containing_oneof = _INBOUNDMESSAGEBODY.oneofs_by_name['entry']
_INBOUNDMESSAGEBODY.oneofs_by_name['entry'].fields.append(
  _INBOUNDMESSAGEBODY.fields_by_name['media'])
_INBOUNDMESSAGEBODY.fields_by_name['media'].containing_oneof = _INBOUNDMESSAGEBODY.oneofs_by_name['entry']
_INBOUNDMESSAGEBODY.oneofs_by_name['entry'].fields.append(
  _INBOUNDMESSAGEBODY.fields_by_name['location'])
_INBOUNDMESSAGEBODY.fields_by_name['location'].containing_oneof = _INBOUNDMESSAGEBODY.oneofs_by_name['entry']
_INBOUNDMESSAGEBODY.oneofs_by_name['entry'].fields.append(
  _INBOUNDMESSAGEBODY.fields_by_name['email'])
_INBOUNDMESSAGEBODY.fields_by_name['email'].containing_oneof = _INBOUNDMESSAGEBODY.oneofs_by_name['entry']
_INBOUNDMESSAGEBODY.oneofs_by_name['entry'].fields.append(
  _INBOUNDMESSAGEBODY.fields_by_name['voice'])
_INBOUNDMESSAGEBODY.fields_by_name['voice'].containing_oneof = _INBOUNDMESSAGEBODY.oneofs_by_name['entry']
_INBOUNDMESSAGEBODY.oneofs_by_name['entry'].fields.append(
  _INBOUNDMESSAGEBODY.fields_by_name['ussd'])
_INBOUNDMESSAGEBODY.fields_by_name['ussd'].containing_oneof = _INBOUNDMESSAGEBODY.oneofs_by_name['entry']
_OUTBOUNDMESSAGEREPLYPROMPT.fields_by_name['action'].enum_type = _PROMPTMESSAGEREPLYACTION
_OUTBOUNDMESSAGEREPLYPROMPT.fields_by_name['menu'].message_type = _PROMPTMESSAGEMENUITEMBODY
_OUTBOUNDMESSAGE.fields_by_name['body'].message_type = _OUTBOUNDMESSAGEBODY
_OUTBOUNDMESSAGE.fields_by_name['provider_tag'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_OUTBOUNDMESSAGE.fields_by_name['reply_token'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_OUTBOUNDMESSAGE.fields_by_name['reply_prompt'].message_type = _OUTBOUNDMESSAGEREPLYPROMPT
DESCRIPTOR.message_types_by_name['MessagingChannelNumber'] = _MESSAGINGCHANNELNUMBER
DESCRIPTOR.message_types_by_name['MediaMessageBody'] = _MEDIAMESSAGEBODY
DESCRIPTOR.message_types_by_name['LocationMessageBody'] = _LOCATIONMESSAGEBODY
DESCRIPTOR.message_types_by_name['EmailMessageBody'] = _EMAILMESSAGEBODY
DESCRIPTOR.message_types_by_name['TemplateMessageBody'] = _TEMPLATEMESSAGEBODY
DESCRIPTOR.message_types_by_name['SayCallAction'] = _SAYCALLACTION
DESCRIPTOR.message_types_by_name['PlayCallAction'] = _PLAYCALLACTION
DESCRIPTOR.message_types_by_name['GetDigitsCallAction'] = _GETDIGITSCALLACTION
DESCRIPTOR.message_types_by_name['GetRecordingCallAction'] = _GETRECORDINGCALLACTION
DESCRIPTOR.message_types_by_name['RecordSessionCallAction'] = _RECORDSESSIONCALLACTION
DESCRIPTOR.message_types_by_name['DialCallAction'] = _DIALCALLACTION
DESCRIPTOR.message_types_by_name['EnqueueCallAction'] = _ENQUEUECALLACTION
DESCRIPTOR.message_types_by_name['DequeueCallAction'] = _DEQUEUECALLACTION
DESCRIPTOR.message_types_by_name['RejectCallAction'] = _REJECTCALLACTION
DESCRIPTOR.message_types_by_name['RedirectCallAction'] = _REDIRECTCALLACTION
DESCRIPTOR.message_types_by_name['VoiceCallAction'] = _VOICECALLACTION
DESCRIPTOR.message_types_by_name['VoiceCallDialplanMessageBody'] = _VOICECALLDIALPLANMESSAGEBODY
DESCRIPTOR.message_types_by_name['VoiceCallDialInput'] = _VOICECALLDIALINPUT
DESCRIPTOR.message_types_by_name['VoiceCallQueueInput'] = _VOICECALLQUEUEINPUT
DESCRIPTOR.message_types_by_name['VoiceCallInputMessageBody'] = _VOICECALLINPUTMESSAGEBODY
DESCRIPTOR.message_types_by_name['UssdMenuMessageBody'] = _USSDMENUMESSAGEBODY
DESCRIPTOR.message_types_by_name['OutboundMessageBody'] = _OUTBOUNDMESSAGEBODY
DESCRIPTOR.message_types_by_name['PromptMessageMenuItemBody'] = _PROMPTMESSAGEMENUITEMBODY
DESCRIPTOR.message_types_by_name['InboundMessageBody'] = _INBOUNDMESSAGEBODY
DESCRIPTOR.message_types_by_name['OutboundMessageReplyPrompt'] = _OUTBOUNDMESSAGEREPLYPROMPT
DESCRIPTOR.message_types_by_name['OutboundMessage'] = _OUTBOUNDMESSAGE
DESCRIPTOR.enum_types_by_name['MessagingChannel'] = _MESSAGINGCHANNEL
DESCRIPTOR.enum_types_by_name['MessagingConsentUpdate'] = _MESSAGINGCONSENTUPDATE
DESCRIPTOR.enum_types_by_name['MessagingConsentUpdateStatus'] = _MESSAGINGCONSENTUPDATESTATUS
DESCRIPTOR.enum_types_by_name['MessagingSessionEndReason'] = _MESSAGINGSESSIONENDREASON
DESCRIPTOR.enum_types_by_name['MessageReaction'] = _MESSAGEREACTION
DESCRIPTOR.enum_types_by_name['PromptMessageReplyAction'] = _PROMPTMESSAGEREPLYACTION
DESCRIPTOR.enum_types_by_name['MessageDeliveryStatus'] = _MESSAGEDELIVERYSTATUS
DESCRIPTOR.enum_types_by_name['VoiceCallStatus'] = _VOICECALLSTATUS
DESCRIPTOR.enum_types_by_name['VoiceCallHangupCause'] = _VOICECALLHANGUPCAUSE
DESCRIPTOR.enum_types_by_name['TextToSpeechVoice'] = _TEXTTOSPEECHVOICE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MessagingChannelNumber = _reflection.GeneratedProtocolMessageType('MessagingChannelNumber', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGINGCHANNELNUMBER,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.MessagingChannelNumber)
  })
_sym_db.RegisterMessage(MessagingChannelNumber)

MediaMessageBody = _reflection.GeneratedProtocolMessageType('MediaMessageBody', (_message.Message,), {
  'DESCRIPTOR' : _MEDIAMESSAGEBODY,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.MediaMessageBody)
  })
_sym_db.RegisterMessage(MediaMessageBody)

LocationMessageBody = _reflection.GeneratedProtocolMessageType('LocationMessageBody', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONMESSAGEBODY,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.LocationMessageBody)
  })
_sym_db.RegisterMessage(LocationMessageBody)

EmailMessageBody = _reflection.GeneratedProtocolMessageType('EmailMessageBody', (_message.Message,), {
  'DESCRIPTOR' : _EMAILMESSAGEBODY,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.EmailMessageBody)
  })
_sym_db.RegisterMessage(EmailMessageBody)

TemplateMessageBody = _reflection.GeneratedProtocolMessageType('TemplateMessageBody', (_message.Message,), {

  'ParamsEntry' : _reflection.GeneratedProtocolMessageType('ParamsEntry', (_message.Message,), {
    'DESCRIPTOR' : _TEMPLATEMESSAGEBODY_PARAMSENTRY,
    '__module__' : 'messaging_model_pb2'
    # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.TemplateMessageBody.ParamsEntry)
    })
  ,
  'DESCRIPTOR' : _TEMPLATEMESSAGEBODY,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.TemplateMessageBody)
  })
_sym_db.RegisterMessage(TemplateMessageBody)
_sym_db.RegisterMessage(TemplateMessageBody.ParamsEntry)

SayCallAction = _reflection.GeneratedProtocolMessageType('SayCallAction', (_message.Message,), {
  'DESCRIPTOR' : _SAYCALLACTION,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.SayCallAction)
  })
_sym_db.RegisterMessage(SayCallAction)

PlayCallAction = _reflection.GeneratedProtocolMessageType('PlayCallAction', (_message.Message,), {
  'DESCRIPTOR' : _PLAYCALLACTION,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.PlayCallAction)
  })
_sym_db.RegisterMessage(PlayCallAction)

GetDigitsCallAction = _reflection.GeneratedProtocolMessageType('GetDigitsCallAction', (_message.Message,), {
  'DESCRIPTOR' : _GETDIGITSCALLACTION,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.GetDigitsCallAction)
  })
_sym_db.RegisterMessage(GetDigitsCallAction)

GetRecordingCallAction = _reflection.GeneratedProtocolMessageType('GetRecordingCallAction', (_message.Message,), {
  'DESCRIPTOR' : _GETRECORDINGCALLACTION,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.GetRecordingCallAction)
  })
_sym_db.RegisterMessage(GetRecordingCallAction)

RecordSessionCallAction = _reflection.GeneratedProtocolMessageType('RecordSessionCallAction', (_message.Message,), {
  'DESCRIPTOR' : _RECORDSESSIONCALLACTION,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.RecordSessionCallAction)
  })
_sym_db.RegisterMessage(RecordSessionCallAction)

DialCallAction = _reflection.GeneratedProtocolMessageType('DialCallAction', (_message.Message,), {
  'DESCRIPTOR' : _DIALCALLACTION,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.DialCallAction)
  })
_sym_db.RegisterMessage(DialCallAction)

EnqueueCallAction = _reflection.GeneratedProtocolMessageType('EnqueueCallAction', (_message.Message,), {
  'DESCRIPTOR' : _ENQUEUECALLACTION,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.EnqueueCallAction)
  })
_sym_db.RegisterMessage(EnqueueCallAction)

DequeueCallAction = _reflection.GeneratedProtocolMessageType('DequeueCallAction', (_message.Message,), {
  'DESCRIPTOR' : _DEQUEUECALLACTION,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.DequeueCallAction)
  })
_sym_db.RegisterMessage(DequeueCallAction)

RejectCallAction = _reflection.GeneratedProtocolMessageType('RejectCallAction', (_message.Message,), {
  'DESCRIPTOR' : _REJECTCALLACTION,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.RejectCallAction)
  })
_sym_db.RegisterMessage(RejectCallAction)

RedirectCallAction = _reflection.GeneratedProtocolMessageType('RedirectCallAction', (_message.Message,), {
  'DESCRIPTOR' : _REDIRECTCALLACTION,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.RedirectCallAction)
  })
_sym_db.RegisterMessage(RedirectCallAction)

VoiceCallAction = _reflection.GeneratedProtocolMessageType('VoiceCallAction', (_message.Message,), {
  'DESCRIPTOR' : _VOICECALLACTION,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.VoiceCallAction)
  })
_sym_db.RegisterMessage(VoiceCallAction)

VoiceCallDialplanMessageBody = _reflection.GeneratedProtocolMessageType('VoiceCallDialplanMessageBody', (_message.Message,), {
  'DESCRIPTOR' : _VOICECALLDIALPLANMESSAGEBODY,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.VoiceCallDialplanMessageBody)
  })
_sym_db.RegisterMessage(VoiceCallDialplanMessageBody)

VoiceCallDialInput = _reflection.GeneratedProtocolMessageType('VoiceCallDialInput', (_message.Message,), {
  'DESCRIPTOR' : _VOICECALLDIALINPUT,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.VoiceCallDialInput)
  })
_sym_db.RegisterMessage(VoiceCallDialInput)

VoiceCallQueueInput = _reflection.GeneratedProtocolMessageType('VoiceCallQueueInput', (_message.Message,), {
  'DESCRIPTOR' : _VOICECALLQUEUEINPUT,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.VoiceCallQueueInput)
  })
_sym_db.RegisterMessage(VoiceCallQueueInput)

VoiceCallInputMessageBody = _reflection.GeneratedProtocolMessageType('VoiceCallInputMessageBody', (_message.Message,), {
  'DESCRIPTOR' : _VOICECALLINPUTMESSAGEBODY,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.VoiceCallInputMessageBody)
  })
_sym_db.RegisterMessage(VoiceCallInputMessageBody)

UssdMenuMessageBody = _reflection.GeneratedProtocolMessageType('UssdMenuMessageBody', (_message.Message,), {
  'DESCRIPTOR' : _USSDMENUMESSAGEBODY,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.UssdMenuMessageBody)
  })
_sym_db.RegisterMessage(UssdMenuMessageBody)

OutboundMessageBody = _reflection.GeneratedProtocolMessageType('OutboundMessageBody', (_message.Message,), {
  'DESCRIPTOR' : _OUTBOUNDMESSAGEBODY,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.OutboundMessageBody)
  })
_sym_db.RegisterMessage(OutboundMessageBody)

PromptMessageMenuItemBody = _reflection.GeneratedProtocolMessageType('PromptMessageMenuItemBody', (_message.Message,), {
  'DESCRIPTOR' : _PROMPTMESSAGEMENUITEMBODY,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.PromptMessageMenuItemBody)
  })
_sym_db.RegisterMessage(PromptMessageMenuItemBody)

InboundMessageBody = _reflection.GeneratedProtocolMessageType('InboundMessageBody', (_message.Message,), {
  'DESCRIPTOR' : _INBOUNDMESSAGEBODY,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.InboundMessageBody)
  })
_sym_db.RegisterMessage(InboundMessageBody)

OutboundMessageReplyPrompt = _reflection.GeneratedProtocolMessageType('OutboundMessageReplyPrompt', (_message.Message,), {
  'DESCRIPTOR' : _OUTBOUNDMESSAGEREPLYPROMPT,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.OutboundMessageReplyPrompt)
  })
_sym_db.RegisterMessage(OutboundMessageReplyPrompt)

OutboundMessage = _reflection.GeneratedProtocolMessageType('OutboundMessage', (_message.Message,), {
  'DESCRIPTOR' : _OUTBOUNDMESSAGE,
  '__module__' : 'messaging_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.OutboundMessage)
  })
_sym_db.RegisterMessage(OutboundMessage)


_TEMPLATEMESSAGEBODY_PARAMSENTRY._options = None
# @@protoc_insertion_point(module_scope)
